/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.component.couchdb.consumer;

import org.apache.camel.component.couchdb.CouchDbConsumer;
import org.apache.camel.processor.resume.TransientResumeStrategy;
import org.apache.camel.resume.ResumeStrategy;

public final class CouchDbResumeStrategyFactory {
    private CouchDbResumeStrategyFactory() {
    }

    public static ResumeStrategy newResumeStrategy(CouchDbConsumer consumer) {
        ResumeStrategy resumeStrategy = consumer.getResumeStrategy();

        if (resumeStrategy == null) {
            resumeStrategy = new TransientResumeStrategy(new LatestUpdateSequenceResumeAdapter());
        }

        return resumeStrategy;
    }
}
